You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by se...@apache.org on 2010/10/04 11:10:07 UTC

svn commit: r1004153 - in /directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap: ./ aci/ aci/protectedItem/

Author: seelmann
Date: Mon Oct  4 09:10:06 2010
New Revision: 1004153

URL: http://svn.apache.org/viewvc?rev=1004153&view=rev
Log:
Added Javadoc; Minor refactorings; Removed unused variable

Modified:
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/RuntimeMultiException.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemChecker.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemParser.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACITuple.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/GrantAndDenial.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemFirstACIItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemPermission.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/MicroOperation.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/Permission.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemChecker.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemCheckerLexer.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemLexer.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserClass.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserFirstACIItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserPermission.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AbstractAttributeTypeProtectedItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllAttributeValuesItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesAndValuesItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AttributeTypeItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/ClassesItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/EntryItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxImmSubItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountElem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RangeOfValuesItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByElem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByItem.java
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/SelfValueItem.java

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/RuntimeMultiException.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/RuntimeMultiException.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/RuntimeMultiException.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/RuntimeMultiException.java Mon Oct  4 09:10:06 2010
@@ -36,6 +36,7 @@ import java.util.Iterator;
  */
 public class RuntimeMultiException extends RuntimeException
 {
+    /** The serialVersionUID. */
     private static final long serialVersionUID = 8582253398936366771L;
 
     /** Collection of nested exceptions. */

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemChecker.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemChecker.java Mon Oct  4 09:10:06 2010
@@ -46,18 +46,17 @@ public class ACIItemChecker
     /** the antlr generated lexer being wrapped */
     private ReusableAntlrACIItemLexer lexer;
 
-    private final boolean isNormalizing;
-
 
     /**
      * Creates a ACIItem parser.
+     *
+     * @param schemaManager the schema manager
      */
     public ACIItemChecker( SchemaManager schemaManager )
     {
         this.lexer = new ReusableAntlrACIItemLexer( new StringReader( "" ) );
         this.checker = new ReusableAntlrACIItemParser( lexer );
         this.checker.init( schemaManager );
-        this.isNormalizing = false;
     }
 
 
@@ -106,14 +105,4 @@ public class ACIItemChecker
         }
     }
 
-
-    /**
-     * Tests to see if this parser is normalizing.
-     * 
-     * @return true if it normalizes false otherwise
-     */
-    public boolean isNormizing()
-    {
-        return this.isNormalizing;
-    }
 }

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemParser.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemParser.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemParser.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemParser.java Mon Oct  4 09:10:06 2010
@@ -47,25 +47,33 @@ public class ACIItemParser
     /** the antlr generated lexer being wrapped */
     private ReusableAntlrACIItemLexer lexer;
 
+    /** The is normalizing flag. */
     private final boolean isNormalizing;
 
 
     /**
      * Creates a ACIItem parser.
+     *
+     * @param schemaManager the schema manager
      */
     public ACIItemParser( SchemaManager schemaManager )
     {
         this.lexer = new ReusableAntlrACIItemLexer( new StringReader( "" ) );
         this.parser = new ReusableAntlrACIItemParser( lexer );
 
-        this.parser.init( schemaManager ); // this method MUST be called while we cannot do
+        // this method MUST be called while we cannot do
         // constructor overloading for antlr generated parser
+        this.parser.init( schemaManager );
+        
         this.isNormalizing = false;
     }
 
 
     /**
      * Creates a normalizing ACIItem parser.
+     *
+     * @param normalizer the normalizer
+     * @param schemaManager the schema manager
      */
     public ACIItemParser( NameComponentNormalizer normalizer, SchemaManager schemaManager )
     {
@@ -73,9 +81,11 @@ public class ACIItemParser
         this.parser = new ReusableAntlrACIItemParser( lexer );
 
         this.parser.setNormalizer( normalizer );
-        this.parser.init( schemaManager ); // this method MUST be called while we cannot do
-        // constructor overloading for antlr generated parser
         this.isNormalizing = true;
+
+        // this method MUST be called while we cannot do
+        // constructor overloading for antlr generated parser
+        this.parser.init( schemaManager ); 
     }
 
 

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACITuple.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACITuple.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACITuple.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACITuple.java Mon Oct  4 09:10:06 2010
@@ -63,16 +63,16 @@ public class ACITuple
      * @param userClasses the collection of {@link UserClass}es this tuple relates to
      * @param authenticationLevel the level of authentication required
      * @param protectedItems the collection of {@link ProtectedItem}s this tuple relates
-     * @param microOperations the set of {@link MicroOperation}s this tuple relates
+     * @param microOperations the collection of {@link MicroOperation}s this tuple relates
      * @param grant <tt>true</tt> if and only if this tuple grants an access
      * @param precedence the precedence of this tuple (<tt>0</tt>-<tt>255</tt>)
      */
-    public ACITuple( 
-            Collection<UserClass> userClasses, 
-            AuthenticationLevel authenticationLevel, 
+    public ACITuple(
+            Collection<UserClass> userClasses,
+            AuthenticationLevel authenticationLevel,
             Collection<ProtectedItem> protectedItems,
-            Set<MicroOperation> microOperations, 
-            boolean grant, 
+            Collection<MicroOperation> microOperations,
+            boolean grant,
             Integer precedence )
     {
         if ( authenticationLevel == null )
@@ -95,7 +95,9 @@ public class ACITuple
 
 
     /**
-     * Returns the collection of {@link UserClass}es this tuple relates to.
+     * Gets the collection of {@link UserClass}es this tuple relates to.
+     *
+     * @return the collection of {@link UserClass}es
      */
     public Collection<UserClass> getUserClasses()
     {
@@ -104,7 +106,9 @@ public class ACITuple
 
 
     /**
-     * Returns the level of authentication required.
+     * Gets the level of authentication required.
+     *
+     * @return the authentication level
      */
     public AuthenticationLevel getAuthenticationLevel()
     {
@@ -113,7 +117,9 @@ public class ACITuple
 
 
     /**
-     * Returns the collection of {@link ProtectedItem}s this tuple relates.
+     * Gets the collection of {@link ProtectedItem}s this tuple relates.
+     *
+     * @return the collection of {@link ProtectedItem}s
      */
     public Collection<ProtectedItem> getProtectedItems()
     {
@@ -122,16 +128,20 @@ public class ACITuple
 
 
     /**
-     * Returns the set of {@link MicroOperation}s this tuple relates.
+     * Gets the collection of {@link MicroOperation}s this tuple relates.
+     *
+     * @return the collection of {@link MicroOperation}s
      */
-    public Set<MicroOperation> getMicroOperations()
+    public Collection<MicroOperation> getMicroOperations()
     {
         return microOperations;
     }
 
 
     /**
-     * Returns <tt>true</tt> if and only if this tuple grants an access.
+     * Gets <tt>true</tt> if and only if this tuple grants an access.
+     *
+     * @return <tt>true</tt> if and only if this tuple grants an access
      */
     public boolean isGrant()
     {
@@ -140,7 +150,9 @@ public class ACITuple
 
 
     /**
-     * Returns the precedence of this tuple (<tt>0</tt>-<tt>255</tt>).
+     * Gets the precedence of this tuple (<tt>0</tt>-<tt>255</tt>).
+     *
+     * @return the precedence
      */
     public Integer getPrecedence()
     {
@@ -148,6 +160,10 @@ public class ACITuple
     }
 
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
     public String toString()
     {
         return "ACITuple: userClasses=" + userClasses + ", " + "authenticationLevel=" + authenticationLevel + ", "

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/GrantAndDenial.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/GrantAndDenial.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/GrantAndDenial.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/GrantAndDenial.java Mon Oct  4 09:10:06 2010
@@ -113,16 +113,20 @@ public final class GrantAndDenial
     /** Denial for {@link MicroOperation#INVOKE} */
     public static final GrantAndDenial DENY_INVOKE = new GrantAndDenial( MicroOperation.INVOKE, 25, false );
 
+    /** The micro operation. */
     private final MicroOperation microOperation;
 
+    /** The code number. */
     private final int code;
 
+    /** The name. */
     private final String name;
 
+    /** The grant flag. */
     private final boolean grant;
 
 
-    private GrantAndDenial(MicroOperation microOperation, int code, boolean grant)
+    private GrantAndDenial( MicroOperation microOperation, int code, boolean grant )
     {
         this.microOperation = microOperation;
         this.code = code;
@@ -132,7 +136,9 @@ public final class GrantAndDenial
 
 
     /**
-     * Returns the {@link MicroOperation} related with this grant or denial.
+     * Gets the {@link MicroOperation} related with this grant or denial.
+     *
+     * @return the micro operation
      */
     public MicroOperation getMicroOperation()
     {
@@ -141,7 +147,9 @@ public final class GrantAndDenial
 
 
     /**
-     * Return the code number of this grant or denial.
+     * Gets the code number of this grant or denial.
+     *
+     * @return the code number
      */
     public int getCode()
     {
@@ -150,7 +158,9 @@ public final class GrantAndDenial
 
 
     /**
-     * Returns the name of this grant or denial.
+     * Gets the name of this grant or denial.
+     *
+     * @return the name
      */
     public String getName()
     {
@@ -160,6 +170,8 @@ public final class GrantAndDenial
 
     /**
      * Returns <tt>true</tt> if and only if this is grant.
+     *
+     * @return <tt>true</tt> if and only if this is grant
      */
     public boolean isGrant()
     {
@@ -167,6 +179,10 @@ public final class GrantAndDenial
     }
 
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
     public String toString()
     {
         return name;

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemFirstACIItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemFirstACIItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemFirstACIItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemFirstACIItem.java Mon Oct  4 09:10:06 2010
@@ -63,7 +63,9 @@ public class ItemFirstACIItem extends AC
 
 
     /**
-     * Returns the collection of {@link ProtectedItem}s.
+     * Gets the collection of {@link ProtectedItem}s.
+     *
+     * @return the collection of {@link ProtectedItem}s
      */
     public Collection<ProtectedItem> getProtectedItems()
     {
@@ -72,7 +74,9 @@ public class ItemFirstACIItem extends AC
 
 
     /**
-     * Returns the collection of {@link ItemPermission}s.
+     * Gets the collection of {@link ItemPermission}s.
+     *
+     * @return the collection of {@link ItemPermission}s
      */
     public Collection<ItemPermission> getItemPermissions()
     {
@@ -81,24 +85,25 @@ public class ItemFirstACIItem extends AC
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         StringBuilder buf = new StringBuilder();
-        
+
         buf.append( "{" );
         buf.append( super.toString() );
-        
+
         // itemOrUserFirst
         buf.append( ", itemOrUserFirst itemFirst: { " );
-        
+
         // protectedItems
         buf.append( "protectedItems { " );
-        
+
         boolean isFirst = true;
 
-        for ( ProtectedItem item:protectedItems )
+        for ( ProtectedItem item : protectedItems )
         {
             if ( isFirst )
             {
@@ -116,8 +121,8 @@ public class ItemFirstACIItem extends AC
         buf.append( " }, itemPermissions { " );
 
         isFirst = true;
-        
-        for ( ItemPermission permission:itemPermissions )
+
+        for ( ItemPermission permission : itemPermissions )
         {
             if ( isFirst )
             {
@@ -132,7 +137,7 @@ public class ItemFirstACIItem extends AC
         }
 
         buf.append( " } } }" );
-        
+
         return buf.toString();
     }
 
@@ -145,8 +150,8 @@ public class ItemFirstACIItem extends AC
     public Collection<ACITuple> toTuples()
     {
         Collection<ACITuple> tuples = new ArrayList<ACITuple>();
-        
-        for ( ItemPermission itemPermission:itemPermissions )
+
+        for ( ItemPermission itemPermission : itemPermissions )
         {
             Set<GrantAndDenial> grants = itemPermission.getGrants();
             Set<GrantAndDenial> denials = itemPermission.getDenials();
@@ -159,14 +164,14 @@ public class ItemFirstACIItem extends AC
                 tuples.add( new ACITuple( itemPermission.getUserClasses(), getAuthenticationLevel(), protectedItems,
                     toMicroOperations( grants ), true, precedence ) );
             }
-            
+
             if ( denials.size() > 0 )
             {
                 tuples.add( new ACITuple( itemPermission.getUserClasses(), getAuthenticationLevel(), protectedItems,
                     toMicroOperations( denials ), false, precedence ) );
             }
         }
-        
+
         return tuples;
     }
 }

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemPermission.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemPermission.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemPermission.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ItemPermission.java Mon Oct  4 09:10:06 2010
@@ -33,6 +33,11 @@ import java.util.Collections;
  */
 public class ItemPermission extends Permission
 {
+
+    /** The serialVersionUID. */
+    private static final long serialVersionUID = 5530483336917026261L;
+
+    /** The user classes. */
     private final Collection<UserClass> userClasses;
 
 
@@ -43,11 +48,12 @@ public class ItemPermission extends Perm
      *            the precedence of this permission (<tt>-1</tt> to use the
      *            default)
      * @param grantsAndDenials
-     *            the set of {@link GrantAndDenial}s
+     *            the collection of {@link GrantAndDenial}s
      * @param userClasses
      *            the collection of {@link UserClass}es
      */
-    public ItemPermission( Integer precedence, Collection<GrantAndDenial> grantsAndDenials, Collection<UserClass> userClasses )
+    public ItemPermission( Integer precedence, Collection<GrantAndDenial> grantsAndDenials,
+        Collection<UserClass> userClasses )
     {
         super( precedence, grantsAndDenials );
 
@@ -56,7 +62,9 @@ public class ItemPermission extends Perm
 
 
     /**
-     * Returns the collection of {@link UserClass}es.
+     * Gets the collection of {@link UserClass}es.
+     *
+     * @return the collection of {@link UserClass}es
      */
     public Collection<UserClass> getUserClasses()
     {
@@ -64,10 +72,14 @@ public class ItemPermission extends Perm
     }
 
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
     public String toString()
     {
         StringBuilder buffer = new StringBuilder();
-        
+
         buffer.append( "{ " );
 
         if ( getPrecedence() != null )
@@ -76,14 +88,14 @@ public class ItemPermission extends Perm
             buffer.append( getPrecedence() );
             buffer.append( ", " );
         }
-        
+
         buffer.append( "userClasses { " );
-        
+
         boolean isFirst = true;
-        
-        for ( UserClass userClass:userClasses )
+
+        for ( UserClass userClass : userClasses )
         {
-            if ( isFirst ) 
+            if ( isFirst )
             {
                 isFirst = false;
             }
@@ -94,12 +106,12 @@ public class ItemPermission extends Perm
 
             buffer.append( userClass.toString() );
         }
-        
+
         buffer.append( " }, grantsAndDenials { " );
-        
+
         isFirst = true;
-        
-        for ( GrantAndDenial grantAndDenial:getGrantsAndDenials() )
+
+        for ( GrantAndDenial grantAndDenial : getGrantsAndDenials() )
         {
             if ( isFirst )
             {
@@ -112,9 +124,9 @@ public class ItemPermission extends Perm
 
             buffer.append( grantAndDenial.toString() );
         }
-        
+
         buffer.append( " } }" );
-        
+
         return buffer.toString();
     }
 }

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/MicroOperation.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/MicroOperation.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/MicroOperation.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/MicroOperation.java Mon Oct  4 09:10:06 2010
@@ -28,49 +28,62 @@ package org.apache.directory.shared.ldap
  */
 public enum MicroOperation
 {
-    // Permissions that may be used in conjunction with any component of
-    // <tt>ProtectedItem</tt>s.
-    ADD( "Add" ),
+    // Permissions that may be used in conjunction with any component of <tt>ProtectedItem</tt>s.
+    /** The Add permission, may be used in conjunction with any component of {@link ProtectedItem}s. */
+    ADD("Add"),
 
-    DISCLOSE_ON_ERROR( "DiscloseOnError" ),
+    /** The DiscloseOnError permission, may be used in conjunction with any component of {@link ProtectedItem}s. */
+    DISCLOSE_ON_ERROR("DiscloseOnError"),
 
-    READ( "Read" ),
+    /** The Read permission, may be used in conjunction with any component of {@link ProtectedItem}s. */
+    READ("Read"),
 
-    REMOVE( "Remove" ),
+    /** The Remove permission, may be used in conjunction with any component of {@link ProtectedItem}s. */
+    REMOVE("Remove"),
 
-    // Permissions that may be used only in conjunction with the entry
-    // component.
-    BROWSE( "Browse" ),
+    // Permissions that may be used only in conjunction with the entry component.
+    /** The Browse permission, may be used only in conjunction with the entry component. */
+    BROWSE("Browse"),
 
-    EXPORT( "Export" ),
+    /** The Export permission, may be used only in conjunction with the entry component. */
+    EXPORT("Export"),
 
-    IMPORT( "Import" ),
+    /** The Import permission, may be used only in conjunction with the entry component. */
+    IMPORT("Import"),
 
-    MODIFY( "Modify" ),
+    /** The Modify permission, may be used only in conjunction with the entry component. */
+    MODIFY("Modify"),
 
-    RENAME ( "Rename" ),
+    /** The Rename permission, may be used only in conjunction with the entry component. */
+    RENAME("Rename"),
 
-    RETURN_DN( "ReturnDN" ),
+    /** The ReturnDN permission, may be used only in conjunction with the entry component. */
+    RETURN_DN("ReturnDN"),
 
-    // Permissions that may be used in conjunction with any component,
-    // except entry, of <tt>ProtectedItem</tt>s.
-    COMPARE( "Compare" ),
+    // Permissions that may be used in conjunction with any component, except entry, of <tt>ProtectedItem</tt>s.
+    /** The Compare permission, may be used in conjunction with any component, except entry. */
+    COMPARE("Compare"),
 
-    FILTER_MATCH( "FilterMatch" ),
+    /** The FilterMatch permission, may be used in conjunction with any component, except entry. */
+    FILTER_MATCH("FilterMatch"),
 
-    INVOKE( "Invoke" );
+    /** The Invoke permission, may be used in conjunction with any component, except entry. */
+    INVOKE("Invoke");
 
+    /** The name. */
     private final String name;
 
 
-    private MicroOperation(String name)
+    private MicroOperation( String name )
     {
         this.name = name;
     }
 
 
     /**
-     * Returns the name of this micro-operation.
+     * Gets the name of this micro-operation.
+     *
+     * @return the name
      */
     public String getName()
     {
@@ -78,6 +91,10 @@ public enum MicroOperation
     }
 
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
     public String toString()
     {
         return name;

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/Permission.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/Permission.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/Permission.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/Permission.java Mon Oct  4 09:10:06 2010
@@ -34,12 +34,19 @@ import java.util.Set;
  */
 public abstract class Permission implements Serializable
 {
+    /** The serialVersionUID. */
+    private static final long serialVersionUID = 8923801399021825709L;
+
+    /** The precedence. */
     private final Integer precedence;
 
+    /** The grants and denials. */
     private final Set<GrantAndDenial> grantsAndDenials;
 
+    /** The grants. */
     private final Set<GrantAndDenial> grants;
 
+    /** The denials. */
     private final Set<GrantAndDenial> denials;
 
 
@@ -52,15 +59,15 @@ public abstract class Permission impleme
      * @param grantsAndDenials
      *            the set of {@link GrantAndDenial}s
      */
-    protected Permission( Integer precedence, Collection<GrantAndDenial> grantsAndDenials)
+    protected Permission( Integer precedence, Collection<GrantAndDenial> grantsAndDenials )
     {
         this.precedence = precedence;
 
         Set<GrantAndDenial> tmpGrantsAndDenials = new HashSet<GrantAndDenial>();
         Set<GrantAndDenial> tmpGrants = new HashSet<GrantAndDenial>();
         Set<GrantAndDenial> tmpDenials = new HashSet<GrantAndDenial>();
-        
-        for ( GrantAndDenial gad:grantsAndDenials )
+
+        for ( GrantAndDenial gad : grantsAndDenials )
         {
             if ( gad.isGrant() )
             {
@@ -81,7 +88,9 @@ public abstract class Permission impleme
 
 
     /**
-     * Returns the precedence of this permission.
+     * Gets the precedence of this permission.
+     *
+     * @return the precedence
      */
     public Integer getPrecedence()
     {
@@ -90,7 +99,9 @@ public abstract class Permission impleme
 
 
     /**
-     * Returns the set of {@link GrantAndDenial}s.
+     * Gets the set of {@link GrantAndDenial}s.
+     *
+     * @return the grants and denials
      */
     public Set<GrantAndDenial> getGrantsAndDenials()
     {
@@ -99,7 +110,9 @@ public abstract class Permission impleme
 
 
     /**
-     * Returns the set of grants only.
+     * Gets the set of grants only.
+     *
+     * @return the grants
      */
     public Set<GrantAndDenial> getGrants()
     {
@@ -108,7 +121,9 @@ public abstract class Permission impleme
 
 
     /**
-     * Returns the set of denials only.
+     * Gets the set of denials only.
+     *
+     * @return the denials
      */
     public Set<GrantAndDenial> getDenials()
     {

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemChecker.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemChecker.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemChecker.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemChecker.java Mon Oct  4 09:10:06 2010
@@ -21,7 +21,6 @@
 package org.apache.directory.shared.ldap.aci;
 
 
-
 import antlr.TokenStream;
 
 

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemCheckerLexer.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemCheckerLexer.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemCheckerLexer.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemCheckerLexer.java Mon Oct  4 09:10:06 2010
@@ -41,8 +41,11 @@ import antlr.LexerSharedInputState;
  */
 class ReusableAntlrACIItemCheckerLexer extends AntlrACIItemCheckerLexer
 {
+
+    /** The saved case sensitive flag. */
     private boolean savedCaseSensitive;
 
+    /** The saved case sensitive literals flag. */
     private boolean savedCaseSensitiveLiterals;
 
 
@@ -52,7 +55,7 @@ class ReusableAntlrACIItemCheckerLexer e
      * @param in
      *            the input to the lexer
      */
-    public ReusableAntlrACIItemCheckerLexer(Reader in)
+    public ReusableAntlrACIItemCheckerLexer( Reader in )
     {
         super( in );
         savedCaseSensitive = getCaseSensitive();

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemLexer.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemLexer.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemLexer.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ReusableAntlrACIItemLexer.java Mon Oct  4 09:10:06 2010
@@ -41,8 +41,11 @@ import antlr.LexerSharedInputState;
  */
 class ReusableAntlrACIItemLexer extends AntlrACIItemLexer
 {
+
+    /** The saved case sensitive flag. */
     private boolean savedCaseSensitive;
 
+    /** The saved case sensitive literals flag. */
     private boolean savedCaseSensitiveLiterals;
 
 
@@ -52,7 +55,7 @@ class ReusableAntlrACIItemLexer extends 
      * @param in
      *            the input to the lexer
      */
-    public ReusableAntlrACIItemLexer(Reader in)
+    public ReusableAntlrACIItemLexer( Reader in )
     {
         super( in );
         savedCaseSensitive = getCaseSensitive();

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserClass.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserClass.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserClass.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserClass.java Mon Oct  4 09:10:06 2010
@@ -36,6 +36,7 @@ import org.apache.directory.shared.ldap.
  */
 public abstract class UserClass implements Serializable
 {
+    /** The serialVersionUID. */
     private static final long serialVersionUID = -123919984184219893L;
 
     /**
@@ -70,6 +71,7 @@ public abstract class UserClass implemen
      */
     public static final class AllUsers extends UserClass
     {
+        /** The serialVersionUID. */
         private static final long serialVersionUID = 8967984720792510292L;
 
 
@@ -95,6 +97,7 @@ public abstract class UserClass implemen
      */
     public static final class ThisEntry extends UserClass
     {
+        /** The serialVersionUID. */
         private static final long serialVersionUID = -8189325270233754470L;
 
 
@@ -103,6 +106,10 @@ public abstract class UserClass implemen
         }
 
 
+        /**
+         * {@inheritDoc}
+         */
+        @Override
         public String toString()
         {
             return "thisEntry";
@@ -114,6 +121,7 @@ public abstract class UserClass implemen
      */
     public static final class ParentOfEntry extends UserClass
     {
+        /** The serialVersionUID. */
         private static final long serialVersionUID = 5247207736068086476L;
 
 
@@ -138,7 +146,10 @@ public abstract class UserClass implemen
      */
     private abstract static class NamedUserClass extends UserClass
     {
+        /** The serialVersionUID. */
         private static final long serialVersionUID = 8571875984468893621L;
+
+        /** The names. */
         protected final Set<DN> names;
 
 
@@ -246,6 +257,7 @@ public abstract class UserClass implemen
      */
     public static class Name extends NamedUserClass
     {
+        /** The serialVersionUID. */
         private static final long serialVersionUID = -4168412030168359882L;
 
 
@@ -279,6 +291,7 @@ public abstract class UserClass implemen
      */
     public static class UserGroup extends NamedUserClass
     {
+        /** The serialVersionUID. */
         private static final long serialVersionUID = 8887107815072965807L;
 
 
@@ -310,8 +323,10 @@ public abstract class UserClass implemen
      */
     public static class Subtree extends UserClass
     {
+        /** The serialVersionUID. */
         private static final long serialVersionUID = 3949337699049701332L;
 
+        /** The subtree specifications. */
         protected final Set<SubtreeSpecification> subtreeSpecifications;
 
 

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserFirstACIItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserFirstACIItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserFirstACIItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserFirstACIItem.java Mon Oct  4 09:10:06 2010
@@ -36,10 +36,13 @@ import org.apache.directory.shared.ldap.
  */
 public class UserFirstACIItem extends ACIItem
 {
+    /** The serialVersionUID. */
     private static final long serialVersionUID = 5587483838404246148L;
 
+    /** The user classes. */
     private final Collection<UserClass> userClasses;
 
+    /** The user permissions. */
     private final Collection<UserPermission> userPermissions;
 
 
@@ -58,8 +61,8 @@ public class UserFirstACIItem extends AC
      *            the collection of {@link UserPermission}s each
      *            <tt>protectedItems</tt> will have
      */
-    public UserFirstACIItem(String identificationTag, int precedence, AuthenticationLevel authenticationLevel,
-        Collection<UserClass> userClasses, Collection<UserPermission> userPermissions)
+    public UserFirstACIItem( String identificationTag, int precedence, AuthenticationLevel authenticationLevel,
+        Collection<UserClass> userClasses, Collection<UserPermission> userPermissions )
     {
         super( identificationTag, precedence, authenticationLevel );
 
@@ -69,7 +72,9 @@ public class UserFirstACIItem extends AC
 
 
     /**
-     * Returns the set of {@link UserClass}es.
+     * Gets the collection of {@link UserClass}es.
+     *
+     * @return the collection of {@link UserClass}es
      */
     public Collection<UserClass> getUserClasses()
     {
@@ -78,7 +83,9 @@ public class UserFirstACIItem extends AC
 
 
     /**
-     * Returns the set of {@link UserPermission}s.
+     * Gets the collection of {@link UserPermission}s.
+     *
+     * @return the collection of {@link UserPermission}s
      */
     public Collection<UserPermission> getUserPermission()
     {
@@ -86,34 +93,38 @@ public class UserFirstACIItem extends AC
     }
 
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
     public String toString()
     {
         StringBuilder buf = new StringBuilder();
-        
+
         // identificationTag
         buf.append( "{ identificationTag \"" );
         buf.append( getIdentificationTag() );
         buf.append( "\", " );
-        
+
         // precedence
         buf.append( "precedence " );
         buf.append( getPrecedence() );
         buf.append( ", " );
-        
+
         // authenticationLevel
         buf.append( "authenticationLevel " );
         buf.append( getAuthenticationLevel().getName() );
         buf.append( ", " );
-        
+
         // itemOrUserFirst
         buf.append( "itemOrUserFirst userFirst: { " );
-        
+
         // protectedItems
         buf.append( "userClasses { " );
 
         boolean isFirst = true;
-        
-        for ( UserClass userClass:userClasses )
+
+        for ( UserClass userClass : userClasses )
         {
             if ( isFirst )
             {
@@ -123,18 +134,18 @@ public class UserFirstACIItem extends AC
             {
                 buf.append( ", " );
             }
-            
+
             buf.append( userClass.toString() );
         }
 
         buf.append( " }, " );
-        
+
         // itemPermissions
         buf.append( "userPermissions { " );
 
         isFirst = true;
-        
-        for ( UserPermission permission:userPermissions )
+
+        for ( UserPermission permission : userPermissions )
         {
             if ( isFirst )
             {
@@ -144,27 +155,30 @@ public class UserFirstACIItem extends AC
             {
                 buf.append( ", " );
             }
-            
+
             buf.append( permission.toString() );
         }
-        
+
         buf.append( " } } }" );
 
         return buf.toString();
     }
 
 
+    /**
+     * {@inheritDoc}
+     */
     public Collection<ACITuple> toTuples()
     {
         Collection<ACITuple> tuples = new ArrayList<ACITuple>();
 
-        for ( UserPermission userPermission:userPermissions )
+        for ( UserPermission userPermission : userPermissions )
         {
             Set<GrantAndDenial> grants = userPermission.getGrants();
             Set<GrantAndDenial> denials = userPermission.getDenials();
-            int precedence = userPermission.getPrecedence() != null ? 
-                userPermission.getPrecedence() :
-                this.getPrecedence();
+            int precedence = userPermission.getPrecedence() != null
+                ? userPermission.getPrecedence()
+                    : this.getPrecedence();
 
             if ( grants.size() > 0 )
             {

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserPermission.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserPermission.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserPermission.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/UserPermission.java Mon Oct  4 09:10:06 2010
@@ -32,8 +32,10 @@ import java.util.Collections;
  */
 public class UserPermission extends Permission
 {
+    /** The serialVersionUID. */
     private static final long serialVersionUID = 3940100745409337694L;
 
+    /** The protected items. */
     private final Collection<ProtectedItem> protectedItems;
 
 
@@ -48,7 +50,8 @@ public class UserPermission extends Perm
      * @param protectedItems
      *            the collection of {@link ProtectedItem}s
      */
-    public UserPermission( Integer precedence, Collection<GrantAndDenial> grantsAndDenials, Collection<ProtectedItem> protectedItems )
+    public UserPermission( Integer precedence, Collection<GrantAndDenial> grantsAndDenials,
+        Collection<ProtectedItem> protectedItems )
     {
         super( precedence, grantsAndDenials );
 
@@ -57,7 +60,9 @@ public class UserPermission extends Perm
 
 
     /**
-     * Returns the collection of {@link ProtectedItem}s.
+     * Gets the collection of {@link ProtectedItem}s.
+     *
+     * @return the collection of {@link ProtectedItem}s
      */
     public Collection<ProtectedItem> getProtectedItems()
     {
@@ -65,10 +70,14 @@ public class UserPermission extends Perm
     }
 
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
     public String toString()
     {
         StringBuilder buf = new StringBuilder();
-        
+
         buf.append( "{ " );
 
         if ( getPrecedence() != null )
@@ -77,12 +86,12 @@ public class UserPermission extends Perm
             buf.append( getPrecedence() );
             buf.append( ", " );
         }
-        
+
         buf.append( "protectedItems { " );
-        
+
         boolean isFirst = true;
-        
-        for ( ProtectedItem item:protectedItems )
+
+        for ( ProtectedItem item : protectedItems )
         {
             if ( isFirst )
             {
@@ -92,15 +101,15 @@ public class UserPermission extends Perm
             {
                 buf.append( ", " );
             }
-            
+
             buf.append( item.toString() );
         }
-        
+
         buf.append( " }, grantsAndDenials { " );
 
         isFirst = true;
-        
-        for ( GrantAndDenial grantAndDenial:getGrantsAndDenials() )
+
+        for ( GrantAndDenial grantAndDenial : getGrantsAndDenials() )
         {
             if ( isFirst )
             {
@@ -113,9 +122,9 @@ public class UserPermission extends Perm
 
             buf.append( grantAndDenial.toString() );
         }
-        
+
         buf.append( " } }" );
-        
+
         return buf.toString();
     }
 }

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AbstractAttributeTypeProtectedItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AbstractAttributeTypeProtectedItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AbstractAttributeTypeProtectedItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AbstractAttributeTypeProtectedItem.java Mon Oct  4 09:10:06 2010
@@ -19,6 +19,7 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.Set;
@@ -26,18 +27,20 @@ import java.util.Set;
 import org.apache.directory.shared.ldap.aci.ProtectedItem;
 import org.apache.directory.shared.ldap.schema.AttributeType;
 
+
 /**
  * A base class for all items which protects attribute types (or its values)
  */
 public abstract class AbstractAttributeTypeProtectedItem extends ProtectedItem
 {
+    /** The attribute types. */
     protected final Set<AttributeType> attributeTypes;
 
 
     /**
      * Creates a new instance.
      * 
-     * @param attributeTypes the collection of attirbute IDs
+     * @param attributeTypes the collection of attribute IDs
      */
     protected AbstractAttributeTypeProtectedItem( Set<AttributeType> attributeTypes )
     {
@@ -46,7 +49,9 @@ public abstract class AbstractAttributeT
 
 
     /**
-     * Returns an iterator of all attribute IDs.
+     * Gets an iterator of all attribute types.
+     *
+     * @return the iterator of all attribute types
      */
     public Iterator<AttributeType> iterator()
     {
@@ -93,8 +98,9 @@ public abstract class AbstractAttributeT
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         StringBuilder buf = new StringBuilder();

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllAttributeValuesItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllAttributeValuesItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllAttributeValuesItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllAttributeValuesItem.java Mon Oct  4 09:10:06 2010
@@ -19,10 +19,12 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import java.util.Set;
 
 import org.apache.directory.shared.ldap.schema.AttributeType;
 
+
 /**
  * All attribute value information pertaining to specific attributes.
  */
@@ -40,11 +42,11 @@ public class AllAttributeValuesItem exte
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         return "allAttributeValues " + super.toString();
     }
 }
-

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesAndValuesItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesAndValuesItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesAndValuesItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesAndValuesItem.java Mon Oct  4 09:10:06 2010
@@ -19,8 +19,10 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import org.apache.directory.shared.ldap.aci.ProtectedItem;
 
+
 /**
  * All user attribute information associated with the entry, including all
  * values of all user attributes.
@@ -36,8 +38,9 @@ public class AllUserAttributeTypesAndVal
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         return "allUserAttributeTypesAndValues";

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AllUserAttributeTypesItem.java Mon Oct  4 09:10:06 2010
@@ -19,8 +19,10 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import org.apache.directory.shared.ldap.aci.ProtectedItem;
 
+
 /**
  * All user attribute type information associated with the entry, but not
  * values associated with those attributes.
@@ -36,8 +38,9 @@ public class AllUserAttributeTypesItem e
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         return "allUserAttributeTypes";

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AttributeTypeItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AttributeTypeItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AttributeTypeItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/AttributeTypeItem.java Mon Oct  4 09:10:06 2010
@@ -19,10 +19,12 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import java.util.Set;
 
 import org.apache.directory.shared.ldap.schema.AttributeType;
 
+
 /**
  * Attribute type information pertaining to specific attributes but not
  * values associated with the type.
@@ -41,8 +43,9 @@ public class AttributeTypeItem extends A
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         return "attributeType " + super.toString();

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/ClassesItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/ClassesItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/ClassesItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/ClassesItem.java Mon Oct  4 09:10:06 2010
@@ -19,9 +19,11 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import org.apache.directory.shared.ldap.aci.ProtectedItem;
 import org.apache.directory.shared.ldap.filter.ExprNode;
 
+
 /**
  * The contents of entries (possibly a family member) which are restricted
  * to those that have object class values that satisfy the predicate defined
@@ -32,6 +34,7 @@ import org.apache.directory.shared.ldap.
  */
 public class ClassesItem extends ProtectedItem
 {
+    /** The classes refinement. */
     private final ExprNode classes;
 
 
@@ -46,6 +49,11 @@ public class ClassesItem extends Protect
     }
 
 
+    /**
+     * Gets the classes refinement.
+     *
+     * @return the classes refinement
+     */
     public ExprNode getClasses()
     {
         return classes;
@@ -86,8 +94,9 @@ public class ClassesItem extends Protect
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         StringBuilder buf = new StringBuilder();
@@ -98,4 +107,3 @@ public class ClassesItem extends Protect
         return buf.toString();
     }
 }
-

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/EntryItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/EntryItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/EntryItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/EntryItem.java Mon Oct  4 09:10:06 2010
@@ -19,8 +19,10 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import org.apache.directory.shared.ldap.aci.ProtectedItem;
 
+
 /**
  * The entry contents as a whole. In case of a family member, it also means
  * the entry content of each subordinate family member within the same
@@ -40,8 +42,9 @@ public class EntryItem extends Protected
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         return "entry";

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxImmSubItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxImmSubItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxImmSubItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxImmSubItem.java Mon Oct  4 09:10:06 2010
@@ -51,7 +51,9 @@ public class MaxImmSubItem extends Prote
 
 
     /**
-     * Returns the maximum number of immediate subordinates.
+     * Gets the maximum number of immediate subordinates.
+     *
+     * @return the maximum number of immediate subordinates
      */
     public int getValue()
     {
@@ -93,8 +95,9 @@ public class MaxImmSubItem extends Prote
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         return "maxImmSub " + value;

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountElem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountElem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountElem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountElem.java Mon Oct  4 09:10:06 2010
@@ -19,6 +19,7 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import org.apache.directory.shared.ldap.schema.AttributeType;
 
 
@@ -49,7 +50,9 @@ public class MaxValueCountElem
 
 
     /**
-     * Returns the attribute to limit the maximum count.
+     * Gets the attribute to limit the maximum count.
+     *
+     * @return the attribute type
      */
     public AttributeType getAttributeType()
     {
@@ -58,7 +61,9 @@ public class MaxValueCountElem
 
 
     /**
-     * Returns the maximum count of the attribute allowed.
+     * Gets the maximum count of the attribute allowed.
+     *
+     * @return the maximum count of the attribute allowed
      */
     public int getMaxCount()
     {
@@ -67,8 +72,9 @@ public class MaxValueCountElem
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         return "{ type " + attributeType.getName() + ", maxCount " + maxCount + " }";

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/MaxValueCountItem.java Mon Oct  4 09:10:06 2010
@@ -54,7 +54,9 @@ public class MaxValueCountItem extends P
 
 
     /**
-     * Returns an iterator of all {@link MaxValueCountElem}s.
+     * Gets an iterator of all {@link MaxValueCountElem}s.
+     *
+     * @return an iterator of all {@link MaxValueCountElem}s
      */
     public Iterator<MaxValueCountElem> iterator()
     {
@@ -101,8 +103,9 @@ public class MaxValueCountItem extends P
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         StringBuilder buf = new StringBuilder();

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RangeOfValuesItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RangeOfValuesItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RangeOfValuesItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RangeOfValuesItem.java Mon Oct  4 09:10:06 2010
@@ -19,16 +19,20 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import org.apache.directory.shared.ldap.aci.ProtectedItem;
 import org.apache.directory.shared.ldap.filter.ExprNode;
 
+
 /**
  * Any attribute value which matches the specified filter, i.e. for which
  * the specified filter evaluated on that attribute value would return TRUE.
  */
 public class RangeOfValuesItem extends ProtectedItem
 {
-    private final ExprNode refinement;
+
+    /** The filter. */
+    private final ExprNode filter;
 
 
     /**
@@ -36,23 +40,27 @@ public class RangeOfValuesItem extends P
      * 
      * @param filter the expression
      */
-    public RangeOfValuesItem( ExprNode refinement )
+    public RangeOfValuesItem( ExprNode filter )
     {
-        if ( refinement == null )
+        if ( filter == null )
         {
-            throw new IllegalArgumentException( "refinement" );
+            throw new IllegalArgumentException( "filter" );
         }
 
-        this.refinement = refinement;
+        this.filter = filter;
     }
 
 
     /**
-     * Returns the expression.
+     * Gets the filter.
+     * 
+     * TODO: rename to getFilter()
+     *
+     * @return the filter
      */
     public ExprNode getRefinement()
     {
-        return refinement;
+        return filter;
     }
 
 
@@ -63,7 +71,7 @@ public class RangeOfValuesItem extends P
     public int hashCode()
     {
         int hash = 37;
-        hash = hash * 17 + refinement.hashCode();
+        hash = hash * 17 + filter.hashCode();
         return hash;
     }
 
@@ -82,7 +90,7 @@ public class RangeOfValuesItem extends P
         if ( o instanceof RangeOfValuesItem )
         {
             RangeOfValuesItem that = ( RangeOfValuesItem ) o;
-            return this.refinement.equals( that.refinement );
+            return this.filter.equals( that.filter );
         }
 
         return false;
@@ -97,7 +105,7 @@ public class RangeOfValuesItem extends P
         StringBuilder buf = new StringBuilder();
 
         buf.append( "rangeOfValues " );
-        buf.append( refinement.toString() );
+        buf.append( filter.toString() );
 
         return buf.toString();
     }

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByElem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByElem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByElem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByElem.java Mon Oct  4 09:10:06 2010
@@ -19,6 +19,7 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import org.apache.directory.shared.ldap.schema.AttributeType;
 
 
@@ -27,7 +28,7 @@ import org.apache.directory.shared.ldap.
  */
 public class RestrictedByElem
 {
-    // The AttributeType on which the restriction is applied */
+    /** The AttributeType on which the restriction is applied */
     private AttributeType attributeType;
 
     /** The list of allowed AttributeType values */
@@ -48,7 +49,9 @@ public class RestrictedByElem
 
 
     /**
-     * Returns the attribute type to restrict.
+     * Gets the attribute type to restrict.
+     *
+     * @return the attribute type
      */
     public AttributeType getAttributeType()
     {
@@ -57,8 +60,10 @@ public class RestrictedByElem
 
 
     /**
-     * Returns the attribute type only whose values are allowed in
+     * Gets the attribute type only whose values are allowed in
      * <tt>attributeType</tt>.
+     *
+     * @return the list of allowed AttributeType values
      */
     public AttributeType getValuesIn()
     {
@@ -67,8 +72,9 @@ public class RestrictedByElem
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         return "{ type " + attributeType.getName() + ", valuesIn " + valuesIn.getName() + " }";

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/RestrictedByItem.java Mon Oct  4 09:10:06 2010
@@ -19,12 +19,14 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.Set;
 
 import org.apache.directory.shared.ldap.aci.ProtectedItem;
 
+
 /**
  * Restricts values added to the attribute type to being values that are
  * already present in the same entry as values of the attribute valuesIn. It
@@ -53,7 +55,9 @@ public class RestrictedByItem extends Pr
 
 
     /**
-     * Returns an iterator of all {@link RestrictedByElem}s.
+     * Gets an iterator of all {@link RestrictedByElem}s.
+     *
+     * @return the iterator of all {@link RestrictedByElem}s
      */
     public Iterator<RestrictedByElem> iterator()
     {
@@ -100,8 +104,9 @@ public class RestrictedByItem extends Pr
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         StringBuilder buf = new StringBuilder();

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/SelfValueItem.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/SelfValueItem.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/SelfValueItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/protectedItem/SelfValueItem.java Mon Oct  4 09:10:06 2010
@@ -19,10 +19,12 @@
  */
 package org.apache.directory.shared.ldap.aci.protectedItem;
 
+
 import java.util.Set;
 
 import org.apache.directory.shared.ldap.schema.AttributeType;
 
+
 /**
  * The attribute value assertion corresponding to the current requestor. The
  * protected item selfValue applies only when the access controls are to be
@@ -45,11 +47,11 @@ public class SelfValueItem extends Abstr
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         return "selfValue " + super.toString();
     }
 }
-
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItem.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItem.java Mon Oct  4 09:10:06 2010
@@ -60,12 +60,12 @@ public abstract class ACIItem
         {
             throw new IllegalArgumentException( I18n.err( I18n.ERR_04001_NULL_IDENTIFICATION_TAG ) );
         }
-        
+
         if ( ( precedence < 0 ) || ( precedence > 255 ) )
         {
             throw new IllegalArgumentException( I18n.err( I18n.ERR_04002_BAD_PRECENDENCE, precedence ) );
         }
-        
+
         if ( authenticationLevel == null )
         {
             throw new IllegalArgumentException( I18n.err( I18n.ERR_04003_NULL_AUTHENTICATION_LEVEL ) );
@@ -78,7 +78,9 @@ public abstract class ACIItem
 
 
     /**
-     * Returns the id string of this item.
+     * Gets the id string of this item.
+     *
+     * @return the identification tag
      */
     public String getIdentificationTag()
     {
@@ -87,7 +89,9 @@ public abstract class ACIItem
 
 
     /**
-     * Returns the precedence of this item.
+     * Gets the precedence of this item.
+     *
+     * @return the precedence
      */
     public int getPrecedence()
     {
@@ -96,7 +100,9 @@ public abstract class ACIItem
 
 
     /**
-     * Returns the level of authentication required to this item.
+     * Gets the level of authentication required to this item.
+     *
+     * @return the authentication level
      */
     public AuthenticationLevel getAuthenticationLevel()
     {
@@ -105,36 +111,40 @@ public abstract class ACIItem
 
 
     /**
-     * Converts this item into a collection of {@link ACITuple}s and returns
-     * it.
+     * Converts this item into a collection of {@link ACITuple}s.
+     *
+     * @return the converted collection of {@link ACITuple}
      */
     public abstract Collection<ACITuple> toTuples();
 
 
     /**
      * Converts a set of {@link GrantAndDenial}s into a set of
      * {@link MicroOperation}s and returns it.
      */
-    protected static Set<MicroOperation> toMicroOperations( Set<GrantAndDenial> grantsAndDenials )
+    protected static Collection<MicroOperation> toMicroOperations( Collection<GrantAndDenial> grantsAndDenials )
     {
         Set<MicroOperation> microOps = new HashSet<MicroOperation>();
-        
-        for ( GrantAndDenial grantAndDenial:grantsAndDenials )
+
+        for ( GrantAndDenial grantAndDenial : grantsAndDenials )
         {
             microOps.add( grantAndDenial.getMicroOperation() );
         }
-        
+
         return microOps;
     }
 
 
     /**
-     * @see Object#toString()
+     * {@inheritDoc}
      */
+    @Override
     public String toString()
     {
         StringBuilder buf = new StringBuilder();
-        
+
         // identificationTag
         buf.append( "identificationTag \"" );
         buf.append( getIdentificationTag() );
@@ -142,11 +152,11 @@ public abstract class ACIItem
         // precedence
         buf.append( "\", precedence " );
         buf.append( getPrecedence() );
-        
+
         // authenticationLevel
         buf.append( ", authenticationLevel " );
         buf.append( getAuthenticationLevel().getName() );
-        
+
         return buf.toString();
     }
 }
@@ -105,36 +111,40 @@ public abstract class ACIItem
 
     /**
-     * Converts a set of {@link GrantAndDenial}s into a set of
-     * {@link MicroOperation}s and returns it.
+     * Converts a collection of {@link GrantAndDenial}s into a collection of {@link MicroOperation}s.
+     *
+     * @param grantsAndDenials the grants and denials
+     * @return the collection of {@link MicroOperation}s
      */

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemChecker.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/aci/ACIItemChecker.java?rev=1004153&r1=1004152&r2=1004153&view=diff
==============================================================================